@@ -164,28 +164,28 @@ SWITCH:
     my @arch_packages = getpackages('arch');
     my $cratepkg_re
         = qr/^libru[sz]t-(?<stem>[^+]+?(?<fullversion>-[^+.-]+(?:\.[^+.]+){2})?)(?:\+(?<feature>.+))?-dev$/;
-    foreach my $package ( getpackages() ) {
-        if ( $package =~ /$cratepkg_re/ ) {
+    foreach my $pkg ( getpackages() ) {
+        if ( $pkg =~ /$cratepkg_re/ ) {
             if ( $+{feature} ) {
                 push(
                     @{ $this->{featurepkg} },
-                    {   name     => $package,
+                    {   name     => $pkg,
                         libcrate => $this->{crates}{ $+{stem} }
                     }
                 );
                 next;
             }
-            $this->{libpkg}{$package}{name} = $package;
+            $this->{libpkg}{$pkg}{name} = $pkg;
             my %fullnames;
             if ( $+{fullversion} ) {
-                push @{ $this->{libpkg}{$package}{crates} },
+                push @{ $this->{libpkg}{$pkg}{crates} },
                     $this->{crates}{ $+{stem} };
                 $fullnames{"$+{stem}$+{fullversion}"} = undef;
             }
             deps_iterate(
                 deps_parse(
                     deps_concat(
-                        $control->get_pkg_by_name($package)->{'Provides'}
+                        $control->get_pkg_by_name($pkg)->{'Provides'}
                     ),
                     virtual => 1
                 ),
@@ -196,10 +196,10 @@ SWITCH:
                     {
                         unless ( $this->{crates}{ $+{stem} } ) {
                             error(
-                                "Failed to resolve crate \"$+{stem}\" in cargo metadata for virtual library package \"$package\"."
+                                "Failed to resolve crate \"$+{stem}\" in cargo metadata for virtual library package \"$pkg\"."
                             );
                         }
-                        push @{ $this->{libpkg}{$package}{crates} },
+                        push @{ $this->{libpkg}{$pkg}{crates} },
                             $this->{crates}{ $+{stem} };
                         $fullnames{"$+{stem}$+{fullversion}"} = undef;
                     }
@@ -207,16 +207,16 @@ SWITCH:
                 },
                 )
                 or error(
-                "Failed to parse virtual crate library packages provided by package $package."
+                "Failed to parse virtual crate library packages provided by package $pkg."
                 );
         }
-        elsif ( grep {$package} @arch_packages ) {
+        elsif ( grep {$pkg} @arch_packages ) {
             deps_iterate(
 
                 # TODO: parse as crate names (not package names)
                 deps_parse(
                     deps_concat(
-                        $control->get_pkg_by_name($package)
+                        $control->get_pkg_by_name($pkg)
                             ->{'X-Cargo-Crates'}
                     )
                 ),
@@ -225,34 +225,34 @@ SWITCH:
                     if ($crate) {
                         if ( exists $crate->{binpkg} ) {
                             error(
-                                "Crate $crate->{cratespec} is tied to multiple packages: $crate->{binpkg}{name} and $package."
+                                "Crate $crate->{cratespec} is tied to multiple packages: $crate->{binpkg}{name} and $pkg."
                             );
                         }
-                        push @{ $this->{binpkg}{$package}{crates} }, $crate;
-                        $crate->{binpkg}{name} = $package;
+                        push @{ $this->{binpkg}{$pkg}{crates} }, $crate;
+                        $crate->{binpkg}{name} = $pkg;
                         verbose_print(
-                            "[RUST] Binaries from crate $crate->{cratespec} tied with package $package"
+                            "[RUST] Binaries from crate $crate->{cratespec} tied with package $pkg"
                         );
                     }
                     else {
                         error(
-                            "Failed to resolve crate \"$_[0]->{package}\" in cargo metadata for binary package \"$package\"."
+                            "Failed to resolve crate \"$_[0]->{package}\" in cargo metadata for binary package \"$pkg\"."
                         );
                     }
                     1;
                 },
                 )
                 or
-                error("Failed to parse crates for binary package $package.");
+                error("Failed to parse crates for binary package $pkg.");
             unless ( keys %{ $this->{binpkg} } ) {
 
                # fallback: use arch-specific package when name matches a crate
-                my $crate = $this->{crates}{$package};
+                my $crate = $this->{crates}{$pkg};
                 if ( $crate and not $crate->{binpkg} ) {
-                    push @{ $this->{binpkg}{$package}{crates} }, $crate;
-                    $crate->{binpkg}{name} = $package;
+                    push @{ $this->{binpkg}{$pkg}{crates} }, $crate;
+                    $crate->{binpkg}{name} = $pkg;
                     verbose_print(
-                        "[RUST] Binaries from crate $crate->{cratespec} tied with package $package"
+                        "[RUST] Binaries from crate $crate->{cratespec} tied with package $pkg"
                     );
                 }
             }
